import { parse } from "@babel/parser";
import traverse from "@babel/traverse";
import { printNodeWithBrackets } from "./printNodeWithBrackets.js";
export function preprocess(code, options) {
    const ast = parse(code, {
        // Note: these are a best-guess attempt to match most common syntax features.
        // If users need to modify this list, we should probably add a plugin option.
        plugins: [
            "decoratorAutoAccessors",
            "decorators-legacy",
            "importAssertions",
            ...(/(?:js|x)$/.test(options.filepath) ? ["jsx"] : []),
            "typescript",
        ],
        sourceType: "module",
    });
    const collectedNodes = [];
    function createCollector(property) {
        return ({ node, }) => {
            if (node[property].type !== "BlockStatement") {
                collectedNodes.push(node);
            }
        };
    }
    traverse(ast, {
        DoWhileStatement: createCollector("body"),
        ForInStatement: createCollector("body"),
        ForOfStatement: createCollector("body"),
        ForStatement: createCollector("body"),
        IfStatement: createCollector("consequent"),
        WhileStatement: createCollector("body"),
    });
    let output = "";
    let lastEnd = 0;
    /* eslint-disable @typescript-eslint/no-non-null-assertion */
    for (const collectedNode of collectedNodes) {
        output += code.slice(lastEnd, collectedNode.start);
        output += printNodeWithBrackets(code, collectedNode);
        lastEnd = collectedNode.end;
    }
    /* eslint-enable @typescript-eslint/no-non-null-assertion */
    return output + code.slice(lastEnd);
}
//# sourceMappingURL=preprocess.js.map